@@ -3,13 +3,15 @@ from dataclasses import dataclass
 from enum import Enum
 from typing import List, Optional, Tuple
 
+import pydantic
 from nassl._nassl import OpenSSLError
 from nassl.legacy_ssl_client import LegacySslClient
 
+from sslyze.json.scan_attempt_json import ScanCommandAttemptAsJson
 from sslyze.errors import ServerRejectedTlsHandshake
 from sslyze.plugins.plugin_base import (
     ScanCommandImplementation,
-    ScanCommandExtraArguments,
+    ScanCommandExtraArgument,
     ScanJob,
     ScanCommandResult,
     ScanCommandWrongUsageError,
@@ -32,6 +34,14 @@ class SessionRenegotiationScanResult(ScanCommandResult):
     is_vulnerable_to_client_renegotiation_dos: bool
 
 
+# Identical fields in the JSON output
+SessionRenegotiationScanResultAsJson = pydantic.dataclasses.dataclass(SessionRenegotiationScanResult, frozen=True)
+
+
+class SessionRenegotiationScanAttemptAsJson(ScanCommandAttemptAsJson):
+    result: Optional[SessionRenegotiationScanResultAsJson]  # type: ignore
+
+
 class _ScanJobResultEnum(Enum):
     IS_VULNERABLE_TO_CLIENT_RENEG_DOS = 1
     SUPPORTS_SECURE_RENEG = 2
@@ -73,7 +83,7 @@ class SessionRenegotiationImplementation(ScanCommandImplementation[SessionRenego
 
     @classmethod
     def scan_jobs_for_scan_command(
-        cls, server_info: ServerConnectivityInfo, extra_arguments: Optional[ScanCommandExtraArguments] = None
+        cls, server_info: ServerConnectivityInfo, extra_arguments: Optional[ScanCommandExtraArgument] = None
     ) -> List[ScanJob]:
         if extra_arguments:
             raise ScanCommandWrongUsageError("This plugin does not take extra arguments")
@@ -213,6 +223,9 @@ def _test_client_renegotiation(server_info: ServerConnectivityInfo) -> Tuple[_Sc
             elif "unexpected record" in e.args[0]:
                 # Indy TCP Server with special RSA Token authentication https://github.com/nabla-c0d3/sslyze/issues/483
                 accepts_client_renegotiation = False
+            elif "wrong version number" in e.args[0]:
+                # Seen with exim 4.92-5 + gnutls 3.7.1
+                accepts_client_renegotiation = False
 
             else:
                 raise
